@@ -3,10 +3,8 @@
 
 
 def run_playground():
-    import streamlit.cli as cli
-    import sys
+    import os
     import onelearn
 
     filename = onelearn.__file__.replace("__init__.py", "playground_decision.py")
-    sys.argv = ["0", "run", filename]
-    cli.main()
+    os.system("streamlit run %s" % filename)
